==> cms-db_v0.7.9.tar.gz: admin/blog.php <==
<?php
/*  cms-db  Copyright (C) 2007-2009 Jan Hoffmann
    This program comes with ABSOLUTELY NO WARRANTY; for details see /admin/version.php.
    This is free software, and you are welcome to redistribute it under certain conditions; see /admin/version.php for details.  */
include('checkuser.inc.php');
checkuser('blog');
include('locale.inc.php');
$locale = new LocalizingClass('blog');
?>
<!DOCTYPE html PUBLIC "-//W3C//DTD XHTML 1.0 Strict//EN"
     "http://www.w3.org/TR/xhtml1/DTD/xhtml1-strict.dtd">
<html xmlns="http://www.w3.org/1999/xhtml">
<head>
<title><?php locale('desc_blog') ?></title>
<meta http-equiv="content-type" content="text/html; charset=utf-8" />
<link rel="stylesheet" type="text/css" href="style.css">
</head>
<body>

<h1><?php locale('desc_blog') ?></h1>

<?php
if (isset($_GET['deleted'])) {
	echo '<p class="hint">'.locale('desc_blogentry-deleted',true).'</p>';
}
?>
<p>
	<form action="blogentry.php" method="get">
		<input type="hidden" name="<?php session_name() ?>" value="<?php session_id() ?>" />
		<select name="id" id="entryid">
			<?php
			$articles = array();
			if ($handle = opendir('../data/blog/articles')) {
				while (false !== ($file = readdir($handle))) {
					if ($file != '.' && $file != '..') {
						$articles[] = $file;
					}
				}
				closedir($handle);
			}
			if (count($articles) != 0) {
				$entries = true;
				natsort($articles);
				$articles = array_reverse($articles);
				foreach ($articles as $article) {
					$data = file_get_contents('../data/blog/articles/'.$article.'/content');
					$data = explode("\n", $data, 5);
					$title = $data[0];
					$author = $data[1];
					$time = $data[2];
					$tags = $data[3];
					$text = $data[4];
					echo '<option value="'.$article.'">'.date('Y-m-d', $time).': '.$title.'</option>';
				}
			} else {
				$entries = false;
				echo '<option value="1">&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;‒&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;</option>';
			}
			?>
		</select>
		<input type="submit" name="action_edit" value="<?php locale('button_edit-blogentry') ?>" />
		<?php if ($entries) { ?>
			<input type="submit" name="action_delete" value="<?php locale('link_delete') ?>" />
		<?php } ?>
	</form>
</p>
<p>
	<a href="newblogentry.php?<?php echo SID ?>"><?php locale('link_new-blogentry') ?></a>
</p>

</body>
</html>

==> cms-db_v0.8.1.tar.gz: admin/blog.php <==
<?php
/*  cms-db  Copyright (C) 2007-2010 Jan Hoffmann
    This program comes with ABSOLUTELY NO WARRANTY; for details see /admin/version.php.
    This is free software, and you are welcome to redistribute it under certain conditions; see /admin/version.php for details.  */

define('cms-db', 'backend');

include('checkuser.inc.php');
checkuser('blog');
include('locale.inc.php');
$locale = new LocalizingClass('blog');
?>
<!DOCTYPE html PUBLIC "-//W3C//DTD XHTML 1.0 Strict//EN"
     "http://www.w3.org/TR/xhtml1/DTD/xhtml1-strict.dtd">
<html xmlns="http://www.w3.org/1999/xhtml">
<head>
<title><?php locale('desc_blog') ?></title>
<meta http-equiv="content-type" content="text/html; charset=utf-8" />
<link rel="stylesheet" type="text/css" href="style.css">
</head>
<body>

<h1><?php locale('desc_blog') ?></h1>

<?php
if (isset($_GET['deleted'])) {
	echo '<p class="hint">'.locale('desc_blogentry-deleted',true).'</p>';
}
?>
<p>
	<form action="blogentry.php" method="get">
		<?php echo csrf_protection_form() ?>
		<input type="hidden" name="<?php session_name() ?>" value="<?php session_id() ?>" />
		<select name="id" id="entryid">
			<?php
			$entries = false;

			$drafts = array();
			if ($handle = opendir('../data/blog/.autosave')) {
				while (false !== ($file = readdir($handle))) {
					if (substr($file, 0, 3) === 'new') {
						$drafts[filemtime('../data/blog/.autosave/'.$file)] = $file;
					}
				}
				closedir($handle);
			}
			if (count($drafts) != 0) {
				$entries = true;
				ksort($drafts);
				$drafts = array_reverse($drafts);
				foreach ($drafts as $draft) {
					$data = file_get_contents('../data/blog/.autosave/'.$draft);
					$data = explode("\n", $data, 3);
					$title = $data[0];
					//$tags = $data[1];
					//$text = $data[2];
					echo '<option value="'.$draft.'">'.locale('desc_draft',true).': '.$title.'</option>';
				}
			}

			$articles = array();
			if ($handle = opendir('../data/blog/articles')) {
				while (false !== ($file = readdir($handle))) {
					if ($file != '.' && $file != '..') {
						$articles[] = $file;
					}
				}
				closedir($handle);
			}
			if (count($articles) != 0) {
				$entries = true;
				natsort($articles);
				$articles = array_reverse($articles);
				foreach ($articles as $article) {
					$data = file_get_contents('../data/blog/articles/'.$article.'/content');
					$data = explode("\n", $data, 5);
					$title = $data[0];
					//$author = $data[1];
					$time = $data[2];
					//$tags = $data[3];
					//$text = $data[4];
					$desc = date('Y-m-d', $time);
					if (file_exists('../data/blog/.autosave/'.$article))
						$desc .= ' + '.locale('desc_draft', true);
					echo '<option value="'.$article.'">'.$desc.': '.$title.'</option>';
				}
			}
			if (!$entries) {
				echo '<option value="1">&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;‒&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;</option>';
			}
			?>
		</select>
		<input type="submit" name="action_edit" value="<?php locale('button_edit-blogentry') ?>" />
		<?php if ($entries) { ?>
			<input type="submit" name="action_delete" value="<?php locale('link_delete') ?>" />
		<?php } ?>
	</form>
</p>
<p>
	<a href="newblogentry.php?<?php echo SID; csrf_protection_get_html() ?>"><?php locale('link_new-blogentry') ?></a>
</p>

</body>
</html>
